%define pypi_name autobahn

%bcond_with xbr
%bcond_without nvx

Name:           python-%{pypi_name}
Version:        24.4.2
Release:        %mkrel 4
Summary:        Python networking library for WebSocket and WAMP
License:        MIT
Group:          Development/Python
URL:            https://pypi.org/project/autobahn/
Source0:        %{pypi_source}
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3-devel
BuildRequires:  python3dist(cffi)
BuildRequires:  python3dist(cryptography)
BuildRequires:  python3dist(pynacl)
BuildRequires:  python3dist(twisted)
# tests
BuildRequires:  python3dist(pytest)
BuildRequires:  python3dist(txaio)
BuildRequires:  python3dist(pytest-asyncio)
BuildRequires:  python3dist(argon2-cffi)
BuildRequires:  python3dist(cbor2)
BuildRequires:  python3dist(passlib)

%description
Autobahn a networking library that is part of the Autobahn project and provides
implementations of
* The WebSocket Protocol http://tools.ietf.org/html/rfc6455_
* The Web Application Messaging Protocol (WAMP) http://wamp.ws
for Twisted and asyncio and for writing servers and clients.

%package -n     python3-%{pypi_name}
Summary:        %{summary}
%{?python_provide:%python_provide python3-%{pypi_name}}
Obsoletes:      python-autobahn-doc < 22.12.1
Obsoletes:      python3-autobahn+dev < 24.4.2-2

%description -n python3-%{pypi_name}
Autobahn a networking library that is part of the Autobahn project and provides
implementations of
* The WebSocket Protocol http://tools.ietf.org/html/rfc6455_
* The Web Application Messaging Protocol (WAMP) http://wamp.ws
for Twisted and asyncio and for writing servers and clients.

%pyproject_extras_subpkg -n python3-%{pypi_name} asyncio twisted accelerate compress serialization encryption scram %{?with_nvx:nvx} ui %{?with_xbr:xbr} all

%prep
%autosetup -n %{pypi_name}-%{version} -p1

%if ! %{with xbr}
sed -i -e 's/extras_require_xbr\s\++//' setup.py
%endif
%if ! %{with nvx}
sed -i -e 's/extras_require_nvx\s\++//' setup.py
%endif

%generate_buildrequires
%pyproject_buildrequires

%build
%if ! %{with xbr}
export AUTOBAHN_STRIP_XBR=1
%endif
%if ! %{with nvx}
export AUTOBAHN_USE_NVX=0
%endif
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files %{pypi_name} twisted %{?with_nvx:_nvx*}

%check
# Ignore tests that rely on optional and not packaged deps.
#USE_ASYNCIO=1 %%pytest --pyargs autobahn -k 'not test_no_memory_arg and not test_basic and not test_websocket_custom_loop and not TestSerializer'

%files -n python3-%{pypi_name} -f %{pyproject_files}
%license LICENSE
%doc README.rst
%{_bindir}/wamp
%if %{with xbr}
%{_bindir}/xbrnetwork
%{_bindir}/xbrnetwork-ui
%endif


%changelog
* Wed Jul 02 2025 umeabot <umeabot> 24.4.2-4.mga10
+ Revision: 2243009
- Mageia 10 Mass Rebuild

* Tue Mar 04 2025 daviddavid <daviddavid> 24.4.2-3.mga10
+ Revision: 2160751
- disable tests for now
+ wally <wally>
- rebuild for python3.13

* Tue Aug 20 2024 papoteur <papoteur> 24.4.2-2.mga10
+ Revision: 2087144
- remove extra subpackage dev, not useful and requiring absent packages

* Sun Aug 18 2024 papoteur <papoteur> 24.4.2-1.mga10
+ Revision: 2086892
- new version 24.4.2

* Fri Dec 29 2023 tv <tv> 23.6.2-3.mga10
+ Revision: 2023433
- Rebuild for python-3.12

* Thu Oct 26 2023 papoteur <papoteur> 23.6.2-2.mga10
+ Revision: 2001882
- relax requirement due to new flakes8
- relax requirement due to new flakes8

* Fri Sep 08 2023 papoteur <papoteur> 23.6.2-1.mga10
+ Revision: 1985330
- new 23.6.2

* Sat Feb 04 2023 papoteur <papoteur> 23.1.1-2.mga9
+ Revision: 1938289
- Relax requirements for dev extra

* Fri Jan 20 2023 wally <wally> 23.1.1-1.mga9
+ Revision: 1934559
- new version 23.1.1

* Sun Jan 15 2023 wally <wally> 22.12.1-1.mga9
+ Revision: 1933608
- new version 22.12.1
- enable extras subpkgs

* Sat Apr 02 2022 umeabot <umeabot> 22.1.1-2.mga9
+ Revision: 1840998
- Mageia 9 Mass Rebuild

* Sun Feb 20 2022 joequant <joequant> 22.1.1-1.mga9
+ Revision: 1781719
- fix debug package
- update
- update ifnarch
- update to 22.1.1 / python 3.10

* Sat Mar 27 2021 joequant <joequant> 21.3.1-2.mga9
+ Revision: 1710821
- update to python 3.9

* Tue Mar 09 2021 guillomovitch <guillomovitch> 21.3.1-1.mga9
+ Revision: 1700915
- new version 21.3.1
- new version 21.2.2

* Fri Jan 22 2021 neoclust <neoclust> 20.12.3-1.mga8
+ Revision: 1672894
- New version 20.12.3
- Add P0: Fixes CVE-2020-35678 (mga#28196)
+ shlomif <shlomif>
- New version 20.7.1

* Tue Feb 18 2020 umeabot <umeabot> 19.11.1-2.mga8
+ Revision: 1539628
- Mageia 8 Mass Rebuild

* Mon Dec 09 2019 shlomif <shlomif> 19.11.1-1.mga8
+ Revision: 1465475
- New version 19.11.1

* Sat Oct 12 2019 tv <tv> 19.8.1-2.mga8
+ Revision: 1452228
- BR python3-cryptography for testsuite
- rebuild with python 3.8

* Fri Aug 09 2019 shlomif <shlomif> 19.8.1-1.mga8
+ Revision: 1428444
- New version 19.8.1

* Fri Jul 19 2019 shlomif <shlomif> 19.3.2-1.mga8
+ Revision: 1422976
- mageiaisation
- from fedora


* Sat Mar 23 2019 Julien Enselme <jujens@jujens.eu> - 19.3.2-1
- Update to 19.3.2

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 18.7.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Wed Aug 01 2018 Julien Enselme <jujens@jujens.eu> - 18.7.1-1
- Update to 18.7.1

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 18.6.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 18.6.1-2
- Rebuilt for Python 3.7

* Sat Jun 16 2018 Julien Enselme <jujens@jujens.eu> - 18.6.1-1
- Update to 18.6.1

* Sat May 12 2018 Julien Enselme <jujens@jujens.eu> - 18.5.1-1
- Update to 18.5.1

* Sun Apr 15 2018 Julien Enselme <jujens@jujens.eu> - 18.4.1-2
- Correct requires

* Sun Apr 15 2018 Julien Enselme <jujens@jujens.eu> - 18.4.1-1
- Update to 18.4.1

* Tue Mar 06 2018 Julien Enselme <jujens@jujens.eu> - 18.3.1-1
- Update to 18.3.1

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 17.10.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Mon Jan 15 2018 Iryna Shcherbina <ishcherb@redhat.com> - 17.10.1-2
- Update Python 2 dependency declarations to new packaging standards
  (See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3)

* Mon Nov 06 2017 Julien Enselme <jujens@jujens.eu> - 17.10.1-1
- Update to 17.10.1
- Use %%version to get the sources

* Tue Sep 26 2017 Julien Enselme <jujens@jujens.eu> - 17.9.3-1.gitd398c4d
- Update to 17.9.3

* Thu Sep 14 2017 Julien Enselme <jujens@jujens.eu> - 17.9.2-1.git164106a
- Update to 17.9.2

* Wed Sep 06 2017 Julien Enselme <jujens@jujens.eu> - 17.9.1-1.gitb813019
- Update to 17.9.1

* Sat Aug 19 2017 Julien Enselme <jujens@jujens.eu> - 17.8.1-1.git96543dd
- Update to 17.8.1

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 17.7.1-2.git9ad7878
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sun Jul 23 2017 Julien Enselme <jujens@jujens.eu> - 17.7.1-1.git9ad7878
- Update to 17.7.1

* Sat Jul 01 2017 Julien Enselme <jujens@jujens.eu> - 17.6.2-1.gitbc2a1b3
- Update to 17.6.2

* Sat Jun 10 2017 Julien Enselme <jujens@jujens.eu> - 17.6.1-1.gite69b314
- Update to 17.6.1

* Sun May 07 2017 Julien Enselme <jujens@jujens.eu> - 17.5.1-1.git73bcac2
- Update to 17.5.1

* Tue Apr 18 2017 Julien Enselme <jujens@jujens.eu> - 0.18.2-1.git731228a
- Update to 0.18.2

* Wed Apr 05 2017 Julien Enselme <jujens@jujens.eu> - 0.18.1-1.gitfd7ec41
- Update to 0.18.1

* Tue Feb 28 2017 Julien Enselme <jujens@jujens.eu> - 0.17.2-1.git0eef8c7
- Update to 0.17.2

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.17.0-2.git81d9276
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

*  Mon Dec 26 2016 Julien Enselme <jujens@jujens.eu> - 0.17.0-1.git81d9276
- Update to 0.17.0

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 0.16.0-3.gitade9eb5
- Rebuild for Python 3.6

* Sat Oct 01 2016 Julien Enselme <jujens@jujens.eu> - 0.16.0-2.gitade9eb5
- Fix tests for pytest3

* Sun Sep 18 2016 Julien Enselme <jujens@jujens.eu> - 0.16.0-1.gitade9eb5
- Update to 0.16.0

* Mon Jul 25 2016 Julien Enselme <jujens@jujens.eu> - 0.15.0-1.git43b57f8
- Update to 0.15.0

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.14.0-2.git81f693d
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Mon May 16 2016 Julien Enselme <jujens@jujens.eu> - 0.14.0-1.git81f693d
- Update to 0.14.0

* Sat Feb 27 2016 Julien Enselme <jujens@jujens.eu> - 0.12.1-1.git22b1183
- Update to 0.12.1

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.10.7-3.gita69e704
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Nov 10 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10.7-2.gita69e704
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5

* Sun Sep 6 2015 Julien Enselme <jujens@jujens.eu> - 0.10.7-1.gita69e7048
- Update to 0.10.7

* Sun Sep 6 2015 Julien Enselme <jujens@jujens.eu> - 0.10.6-1.gitb35d99f1
- Update to 0.10.6

* Sat Aug 15 2015 Julien Enselme <jujens@jujens.eu> - 0.10.5-1.git3fce8ac
- Update to 0.10.5.post-2

* Wed Aug 5 2015 Julien Enselme <jujens@jujens.eu> - 0.10.4-3.git29f8acc
- Build python2 and python3 in the same dir
- Update dependencies
- Put python2 package in a subpackage
- Add provides
- Correct %%files section

* Fri Jul 24 2015 Julien Enselme <jujens@jujens.eu> - 0.10.4-2.git29f8acc
- Surround doc package with if
- Remove %%py3dir macro
- Add CFLAGS in %%build

* Sat Jul 18 2015 Julien Enselme <jujens@jujens.eu> - 0.10.4-1.git29f8acc
- Initial packaging
